@@ -2,15 +2,12 @@
 
 from .activate import *  # noqa
 from .active import *  # noqa
-from .add import *  # noqa
 from .config import *  # noqa
-from .clear import *  # noqa
 from .create import *  # noqa
 from .deactivate import *  # noqa
 from .delete import *  # noqa
 from .djshell import *  # noqa
+from .gitignore import *  # noqa
 from .init import *  # noqa
 from .list import *  # noqa
-from .magic import *  # noqa
-from .save import *  # noqa
 from .shell import *  # noqa
